@@ -5,6 +5,11 @@ import numpy as np
 
 import blurredface_sts_test
 import os
+import pkg_resources
+
+def prinfPath():{
+    print(os.path.dirname(os.path.realpath(__file__)))
+}
 
 #打码函数
 # size为打码的方块大小
@@ -24,7 +29,7 @@ def faceRecognizer(filepath):
     img = cv2.imread(filepath)
     # img = cv2.resize(img,(1920,1080),interpolation=cv2.INTER_CUBIC)
 
-    parent = os.path.dirname(os.path.realpath(__file__))
+    # parent = os.path.dirname(os.path.realpath(__file__))
 
     # 转换成灰度图像
     gray_img = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
@@ -34,7 +39,8 @@ def faceRecognizer(filepath):
         # "haarcascades/haarcascade_frontalface_default.xml"
         # "haarcascade_frontalface_default.xml"
         # blurredface_sts_test.haarcascade.haarcascade_frontalface_default
-        parent+"haarcascades/haarcascade_frontalface_default.xml"
+        # parent+"haarcascades/haarcascade_frontalface_default.xml"
+
     )
     classifier_alt_tree = cv2.CascadeClassifier(
         # "haarcascades/haarcascade_frontalface_alt_tree.xml"
